@@ -130,17 +130,17 @@ ev_toolbar_create_menu_button (EvToolbar   *ev_toolbar,
                                GMenuModel  *menu,
                                GtkAlign     menu_align)
 {
-        GtkWidget *button;
-        GtkMenu *popup;
+        GtkWidget  *button;
+        GtkPopover *popup;
 
         button = gtk_menu_button_new ();
-        gtk_menu_button_set_use_popover (GTK_MENU_BUTTON (button), FALSE);
         gtk_widget_set_valign (button, GTK_ALIGN_CENTER);
         gtk_button_set_image (GTK_BUTTON (button), gtk_image_new ());
         gtk_image_set_from_icon_name (GTK_IMAGE (gtk_button_get_image (GTK_BUTTON (button))),
                                       icon_name, GTK_ICON_SIZE_MENU);
         gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (button), menu);
-        popup = gtk_menu_button_get_popup (GTK_MENU_BUTTON (button));
+        popup = gtk_menu_button_get_popover (GTK_MENU_BUTTON (button));
+        gtk_popover_set_position (popup, GTK_POS_BOTTOM);
         gtk_widget_set_halign (GTK_WIDGET (popup), menu_align);
 
         return button;
@@ -195,7 +195,7 @@ ev_toolbar_constructed (GObject *object)
 
         G_OBJECT_CLASS (ev_toolbar_parent_class)->constructed (object);
 
-        builder = gtk_builder_new_from_resource ("/org/gnome/evince/shell/ui/menus.ui");
+        builder = gtk_builder_new_from_resource ("/org/gnome/evince/gtk/menus.ui");
 
         button = ev_toolbar_create_button (ev_toolbar, "win.open",
                                            "document-open-symbolic",
@@ -207,6 +207,8 @@ ev_toolbar_constructed (GObject *object)
         /* Page selector */
         /* Use EvPageActionWidget for now, since the page selector action is also used by the previewer */
         tool_item = GTK_WIDGET (g_object_new (EV_TYPE_PAGE_ACTION_WIDGET, NULL));
+        gtk_widget_set_tooltip_text (tool_item, _("Select page or search in the index"));
+        atk_object_set_name (gtk_widget_get_accessible (tool_item), _("Select page"));
         ev_toolbar->priv->page_selector = tool_item;
         ev_page_action_widget_set_model (EV_PAGE_ACTION_WIDGET (tool_item),
                                          ev_window_get_document_model (ev_toolbar->priv->window));
@@ -257,6 +259,8 @@ ev_toolbar_constructed (GObject *object)
         vbox = ev_zoom_action_new (ev_window_get_document_model (ev_toolbar->priv->window),
                                    G_MENU (gtk_builder_get_object (builder, "zoom-menu")));
         ev_toolbar->priv->zoom_action = vbox;
+        gtk_widget_set_tooltip_text (vbox, _("Select or set the zoom level of the document"));
+        atk_object_set_name (gtk_widget_get_accessible (vbox), _("Set zoom level"));
         g_signal_connect (vbox, "activated",
                           G_CALLBACK (zoom_selector_activated),
                           ev_toolbar);
